camelot.camelot.types.Image

Package camelot :: Package camelot :: Package types :: Class Image |
[hide private]
[frames] | no frames]

# Class Image

source code

Sqlalchemy column type to store images

This column type accepts and returns a StoredImage, and stores them in the directory specified by settings.MEDIA_ROOT. The name of the file is stored as a string in the database.

Instance Methods | [hide private]
__init__(self, max_length=100, upload_to='', prefix='image-', format='png', **kwargs) | source code
bind_processor(self, dialect) | source code
result_processor(self, dialect) | source code

Class Variables | [hide private]
| impl = `types.Unicode`